# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"clean_column_names": "00_core.ipynb",
         "ssb_to_gcs": "01_csv_bq.ipynb",
         "parquet_to_bigquery": "01_csv_bq.ipynb"}

modules = ["core.py",
           "data.py"]

doc_url = "https://docs.datasett.io/"

git_url = "https://github.com/datafabrikken/pypi/tree/master/"

def custom_doc_links(name): return None
