# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/00_core.ipynb (unless otherwise specified).

__all__ = ['clean_column_names', 'clean_column_names']

# Cell
#nbdev_comment _all_ = ['clean_column_names']

# Cell
from nbdev.showdoc import *
import pandas as pd
import os
import re

# Cell
def clean_column_names(s):
    return re.sub('[^a-zA-Z ]+','_', s.lower()
        .replace('ø','o')
        .replace('æ','ae')
        .replace('å','aa')).strip()